# coding: utf-8
# pylint: disable=unused-argument
from __future__ import absolute_import
from __future__ import unicode_literals

from django.db import migrations

from .. import d15n_managers_registry


def _install(apps, schema_editor):
    if schema_editor.connection.alias in d15n_managers_registry:
        manager = d15n_managers_registry.get(schema_editor.connection.alias)
        manager.install()


def _uninstall(apps, schema_editor):
    if schema_editor.connection.alias in d15n_managers_registry:
        manager = d15n_managers_registry.get(schema_editor.connection.alias)
        manager.uninstall()


class Migration(migrations.Migration):

    """Установка/удаление объектов подсистемы деперсонализации.

    .. seealso::

       :meth:`m3_d15n.utils.D15nManager.install`,
       :meth:`m3_d15n.utils.D15nManager.uninstall`.
    """

    dependencies = []

    operations = [
        migrations.RunPython(
            code=_install,
            reverse_code=_uninstall,
        ),
    ]
